@@ -1,11 +1,10 @@
 # -*- perl -*-
 #
 # Module::TestConfig::Question - question interface
+#
+# $Id: Question.pm,v 1.4 2003/08/20 19:24:32 jkeroes Exp $
 
 package Module::TestConfig::Question;
-{
-  $Module::TestConfig::Question::VERSION = '0.06_01';
-}
 
 require 5.005_62;
 use strict;
@@ -27,20 +26,16 @@ sub init {
     my $self = shift;
 
     if ( ref $_[0] eq "ARRAY" ) {
-        my @q = @{+shift};
-        $self->msg(  shift @q ) if @q;
-        $self->name( shift @q ) if @q;
-        $self->def(  shift @q ) if @q;
-        $self->opts( shift @q ) if @q;
+	@{$self}{ qw/msg name default opts/ } = @{$_[0]};
     } else {
-        my %args = ref $_[0] eq "HASH" ? %{$_[0]} : @_;
-        while ( my ( $method, $args ) = each %args ) {
-            if ( $self->can( $method ) ) {
-                $self->$method( $args );
-            } else {
-                croak "Can't handle arg: '$method'. Aborting";
-            }
-        }
+	my %args = ref $_[0] eq "HASH" ? %{$_[0]} : @_;
+	while ( my ( $method, $args ) = each %args ) {
+	    if ( $self->can( $method ) ) {
+		$self->$method( $args );
+	    } else {
+		croak "Can't handle arg: '$method'. Aborting";
+	    }
+	}
     }
 
     return $self;
@@ -68,44 +63,36 @@ sub opts {
     my $self = shift;
 
     if ( @_ ) {
-        my %args = ref $_[0] eq "HASH" ? %{ $_[0] } : @_;
+	my %args = ref $_[0] eq "HASH" ? %{ $_[0] } : @_;
 
-        while ( my ( $method, $args ) = each %args ) {
-            if ( $self->can( $method ) ) {
-                $self->$method( $args );
-            } else {
-                croak "Can't handle opts arg: '$method'. Aborting";
-            }
-        }
+	while ( my ( $method, $args ) = each %args ) {
+	    if ( $self->can( $method ) ) {
+		$self->$method( $args );
+	    } else {
+		croak "Can't handle opts arg: '$method'. Aborting";
+	    }
+	}
     }
 
-    return wantarray
-    ? ( skip     => $self->{skip},
-        validate => $self->{validate},
-        noecho   => $self->{noecho},
-      )
-    : { skip     => $self->{skip},
-        validate => $self->{validate},
-        noecho   => $self->{noecho},
-    };
+    return wantarray ? %{ $self->{opts} } : $self->{opts};
 }
 
 sub skip {
     my $self = shift;
-    $self->{skip} = shift if @_;
-    return $self->{skip};
+    $self->{opts}{skip} = shift if @_;
+    return $self->{opts}{skip};
 }
 
 sub validate {
     my $self = shift;
-    $self->{validate} = shift if @_;
-    return $self->{validate};
+    $self->{opts}{validate} = shift if @_;
+    return $self->{opts}{validate};
 }
 
 sub noecho {
     my $self = shift;
-    $self->{noecho} = shift if @_;
-    return $self->{noecho};
+    $self->{opts}{noecho} = shift if @_;
+    return $self->{opts}{noecho};
 }
 
 # Aliases
@@ -119,23 +106,19 @@ sub noecho {
 
 Module::TestConfig::Question - question interface
 
-=head1 VERSION
-
-version 0.06_01
-
 =head1 SYNOPSIS
 
   use Module::TestConfig::Question;
 
   my $question = Module::TestConfig::Question->new(
-    name => 'toes',
-    msg => 'How many toes do you have?',
-    def => 10,
-    opts => {
-         noecho   => 0,
-         validate => { ... },
-         skip     => sub { ... },
-        }
+	name => 'toes',
+	msg => 'How many toes do you have?',
+	def => 10,
+	opts => {
+		 noecho   => 0,
+		 validate => { ... },
+		 skip     => sub { ... },
+		}
   );
 
 =head1 PUBLIC METHODS
@@ -148,17 +131,13 @@ Args: See L<"SYNOPSIS">
 
 Returns: an object
 
-=item init()
-
-Args: accepts a list, arrayref, or hashref of arguments; see L<"SYNOPSIS">
-
 =item msg()
 
-=item question()
-
 Required. The question we ask of a user. A string. Tends
 to look best when there's a '?' or a ':' on the end.
 
+Aliased as question()
+
 Args: a question to ask the user
 
 Returns: that question
@@ -173,20 +152,20 @@ Returns: that name
 
 =item def()
 
-=item  default()
-
 A question's default answer.
 
+Aliased as default().
+
 Args: a default
 
 Returns: that default
 
 =item opts()
 
-=item options()
-
 See L<"skip()">, L<"validate()"> and L<"noecho()">.
 
+Aliased as options().
+
 Args: A hash or hashref of options.
 
 Returns: the hashref in scalar context, a hash in list context.
@@ -222,11 +201,11 @@ Returns: the current value
 
 =head1 AUTHOR
 
-Joshua Keroes E<lt>joshua@cpan.orgE<gt>
+Joshua Keroes E<lt>jkeroes@eli.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2013 by Joshua Keroes E<lt>joshua@cpan.orgE<gt>
+Copyright 2003 by Joshua Keroes E<lt>jkeroes@eli.netE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
